(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     30897,        779]
NotebookOptionsPosition[     30119,        749]
NotebookOutlinePosition[     30510,        766]
CellTagsIndexPosition[     30467,        763]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"BeginPackage", "[", "\"\<InputUnits`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.600040907438278*^9, 3.600040916918549*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"AddInputAliases", "::", "usage"}], "=", "\"\<AddInputAliases[\!\(\*
StyleBox[\"aliasRule\",
FontSlant->\"Italic\"]\)] adds an input alias to the current Front End \
Session.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6000410445167828`*^9, 3.60004110298177*^9}, {
   3.600041141344063*^9, 3.600041207910293*^9}, 3.600175370791561*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"InputUnits", "::", "usage"}], "=", 
   "\"\<InputUnits is a package that loads input aliases for units. \
AddInputAliases is its only externally-defined function.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.600041212398795*^9, 3.600041284544714*^9}, {
   3.60004132701268*^9, 3.600041358175535*^9}, 3.600175376155547*^9, {
   3.600258505957391*^9, 3.60025853000742*^9}}],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.600041400694392*^9, 3.6000414007109003`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AddInputAliases", "[", "newInputAliases_", "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"oldInputAliases", "=", 
       RowBox[{"InputAliases", "/.", 
        RowBox[{"Options", "[", 
         RowBox[{"$FrontEndSession", ",", "InputAliases"}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"newList", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"ListQ", "[", "newInputAliases", "]"}], ",", 
         "newInputAliases", ",", 
         RowBox[{"{", "newInputAliases", "}"}]}], "]"}]}]}], "}"}], ",", 
    RowBox[{"SetOptions", "[", 
     RowBox[{"$FrontEndSession", ",", 
      RowBox[{"InputAliases", "\[Rule]", 
       RowBox[{"Join", "[", 
        RowBox[{"oldInputAliases", ",", "newList"}], "]"}]}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.582319575189033*^9, 3.582319662981295*^9}, {
   3.582324414042675*^9, 3.58232441740184*^9}, {3.582324473038032*^9, 
   3.582324477931425*^9}, {3.5823250169885283`*^9, 3.582325169507287*^9}, {
   3.5831566516245127`*^9, 3.583156662998527*^9}, {3.5999370525374203`*^9, 
   3.5999370531017733`*^9}, {3.600258779333399*^9, 3.600258780193988*^9}, 
   3.6002643246557283`*^9, 3.600472999584654*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"aliasRule", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"alias_", ",", "unitShort_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"unitMouseOver_", ",", "unitLong_"}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"boxQ", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"StringTake", "[", 
          RowBox[{
           RowBox[{"ToString", "[", 
            RowBox[{"Head", "[", "#", "]"}], "]"}], ",", 
           RowBox[{"-", "3"}]}], "]"}], "===", "\"\<Box\>\""}], "&"}], 
       ")"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"boxedUnitShort", "=", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"boxQ", "[", "unitShort", "]"}], ",", "unitShort", ",", 
           RowBox[{"ToBoxes", "[", "unitShort", "]"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"boxedUnitLong", "=", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"boxQ", "[", "unitLong", "]"}], ",", "unitLong", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"ToBoxes", "[", "unitLong", "]"}], "}"}], "]"}]}], 
          "]"}]}]}], "}"}], ",", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"display", "=", 
          RowBox[{"StyleBox", "[", 
           RowBox[{
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"StyleBox", "[", 
               RowBox[{
               "boxedUnitShort", ",", 
                "\"\<QuantityUnitTraditionalLabel\>\""}], "]"}], "}"}], "]"}],
             ",", 
            RowBox[{"ShowStringCharacters", "\[Rule]", "False"}]}], "]"}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"DFun", "=", 
             RowBox[{"With", "[", 
              RowBox[{
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{"displayMouseOver", "=", 
                 RowBox[{"\"\<Unit: \>\"", "<>", "unitMouseOver"}]}], "}"}], 
               ",", "\[IndentingNewLine]", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"TooltipBox", "[", 
                  RowBox[{"display", ",", "displayMouseOver"}], "]"}], "&"}], 
                ")"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"IFun", "=", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Quantity\>\"", ",", "\"\<[\>\"", ",", "boxedUnitLong", 
                  ",", "\"\<]\>\""}], "}"}], "]"}], "&"}], ")"}]}]}], "}"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"alias", "\[Rule]", 
           RowBox[{"TemplateBox", "[", 
            RowBox[{
             RowBox[{"{", "}"}], ",", "\"\<QuantityUnit\>\"", ",", 
             RowBox[{"DisplayFunction", "\[Rule]", "DFun"}], ",", 
             RowBox[{"InterpretationFunction", "\[Rule]", "IFun"}]}], 
            "]"}]}]}], "]"}]}], "]"}]}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aliasRule", "[", 
   RowBox[{"unitShort_String", ",", "unitLong_"}], "]"}], ":=", 
  RowBox[{"aliasRule", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<q\>\"", "<>", 
       RowBox[{"ToLowerCase", "[", "unitShort", "]"}]}], ",", "unitShort"}], 
     "}"}], ",", "unitLong"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aliasRule", "[", 
   RowBox[{"unitShort_", ",", "unitLong_String"}], "]"}], ":=", 
  RowBox[{"aliasRule", "[", 
   RowBox[{"unitShort", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ToLowerCase", "[", "unitLong", "]"}], ",", "unitLong"}], 
     "}"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.600829785999382*^9, 3.600829794113584*^9}, {
   3.600830320150243*^9, 3.600830326021967*^9}, {3.60083036059345*^9, 
   3.6008303851320143`*^9}, {3.600830555252492*^9, 3.6008306151387997`*^9}, {
   3.60083065531008*^9, 3.600830673662623*^9}, {3.600860826214641*^9, 
   3.600860828572736*^9}, 3.600860921655604*^9, {3.610107537497589*^9, 
   3.6101076353607807`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"AddInputAliases", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\"\<us\>\"", "\[Rule]", "\"\<//UnitSimplify\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
     "\"\<si\>\"", "\[Rule]", "\"\<//UnitConvert[#,\\\"SIBase\\\"]&\>\""}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<m\>\"", ",", "\"\<Meters\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<kg\>\"", ",", "\"\<Kilograms\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<s\>\"", ",", "\"\<Seconds\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<N\>\"", ",", "\"\<Newtons\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<J\>\"", ",", "\"\<Joules\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<W\>\"", ",", "\"\<Watts\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<C\>\"", ",", "\"\<Coulombs\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<V\>\"", ",", "\"\<Volts\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<A\>\"", ",", "\"\<Amperes\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qo\>\"", ",", "\"\<\[CapitalOmega]\>\""}], "}"}], ",", 
       "\"\<Ohms\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<rad\>\"", ",", "\"\<Radians\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<T\>\"", ",", "\"\<Teslas\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<Wb\>\"", ",", "\"\<Webers\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<F\>\"", ",", "\"\<Farads\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<H\>\"", ",", "\"\<Henries\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<Hz\>\"", ",", "\"\<Hertz\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mol\>\"", ",", "\"\<Moles\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qkcal\>\"", ",", "\"\<kcal\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<thermochemical kilocalories\>\"", ",", 
         "\"\<KilocaloriesThermochemical\>\""}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qcal\>\"", ",", "\"\<cal\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<thermochemical kilocalories\>\"", ",", 
         "\"\<CaloriesThermochemical\>\""}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<K\>\"", ",", "\"\<Kelvins\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qdc\>\"", ",", "\"\<\[Degree]C\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<degrees Celsius\>\"", ",", "\"\<DegreesCelsius\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<Pa\>\"", ",", "\"\<Pascals\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<in\>\"", ",", "\"\<Inches\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<ft\>\"", ",", "\"\<Feet\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<yd\>\"", ",", "\"\<Yards\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mi\>\"", ",", "\"\<Miles\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<nmi\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<nautical miles\>\"", ",", "\"\<NauticalMiles\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<fm\>\"", ",", "\"\<Femtometers\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<nm\>\"", ",", "\"\<Nanometers\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmum\>\"", ",", "\"\<\[Mu]m\>\""}], "}"}], ",", 
       "\"\<Microns\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mm\>\"", ",", "\"\<Millimeters\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<cm\>\"", ",", "\"\<Centimeters\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<m\>\"", ",", "\"\<Meters\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<km\>\"", ",", "\"\<Kilometers\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qan\>\"", ",", "\"\<\[CapitalARing]\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[ARing]ngstr\[ODoubleDot]ms\>\"", ",", "\"\<Angstroms\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<au\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<astronomical units\>\"", ",", "\"\<AstronomicalUnit\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<ly\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<light years\>\"", ",", "\"\<LightYears\>\""}], "}"}]}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<pc\>\"", ",", "\"\<Parsecs\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<ns\>\"", ",", "\"\<Nanoseconds\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<ms\>\"", ",", "\"\<Milliseconds\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<s\>\"", ",", "\"\<Seconds\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<min\>\"", ",", "\"\<Minutes\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qhr\>\"", ",", "\"\<h\>\""}], "}"}], ",", 
       "\"\<Hours\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<days\>\"", ",", "\"\<Days\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<yr\>\"", ",", "\"\<Years\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmicg\>\"", ",", "\"\<\[Mu]g\>\""}], "}"}], ",", 
       "\"\<Micrograms\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mg\>\"", ",", "\"\<Milligrams\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<g\>\"", ",", "\"\<Grams\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<kg\>\"", ",", "\"\<Kilograms\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<u\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<unified atomic mass units\>\"", ",", "\"\<AtomicMassUnit\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<slugs\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<slugs\>\"", ",", "\"\<SlugsMass\>\""}], "}"}]}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qlbm\>\"", ",", "\"\<lb\>\""}], "}"}], ",", 
       "\"\<Pounds\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<K\>\"", ",", "\"\<Kelvins\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qdc\>\"", ",", "\"\<\[Degree]C\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<degrees Celsius\>\"", ",", "\"\<DegreesCelsius\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qdf\>\"", ",", "\"\<\[Degree]F\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<degrees Fahrenheit\>\"", ",", "\"\<DegreesFahrenheit\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qdr\>\"", ",", "\"\<\[Degree]R\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<degrees Rankine\>\"", ",", "\"\<DegreesRankine\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<Pa\>\"", ",", "\"\<Pascals\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<kPa\>\"", ",", "\"\<Kilopascals\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<bars\>\"", ",", "\"\<Bars\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mbar\>\"", ",", "\"\<Millibars\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<atm\>\"", ",", "\"\<Atmospheres\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mmHg\>\"", ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<millimeters of mercury\>\"", ",", 
         "\"\<MillimetersOfMercury\>\""}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<Torr\>\"", ",", "\"\<Torr\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<nC\>\"", ",", "\"\<Nanocoulombs\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmicc\>\"", ",", "\"\<\[Mu]C\>\""}], "}"}], ",", 
       "\"\<Microcoulombs\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mC\>\"", ",", "\"\<Millicoulombs\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmicv\>\"", ",", "\"\<\[Mu]V\>\""}], "}"}], ",", 
       "\"\<Microvolts\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mV\>\"", ",", "\"\<Millivolts\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<kV\>\"", ",", "\"\<Kilovolts\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmica\>\"", ",", "\"\<\[Mu]A\>\""}], "}"}], ",", 
       "\"\<Microamperes\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mA\>\"", ",", "\"\<Milliamperes\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmo\>\"", ",", "\"\<m\[CapitalOmega]\>\""}], "}"}], ",", 
       "\"\<Milliohms\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qko\>\"", ",", "\"\<k\[CapitalOmega]\>\""}], "}"}], ",", 
       "\"\<Kiloohms\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmego\>\"", ",", "\"\<M\[CapitalOmega]\>\""}], "}"}], 
       ",", "\"\<Megaohms\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmict\>\"", ",", "\"\<\[Mu]T\>\""}], "}"}], ",", 
       "\"\<Microteslas\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mT\>\"", ",", "\"\<milliteslas\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qgauss\>\"", ",", "\"\<G\>\""}], "}"}], ",", 
       "\"\<Gausses\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<kHz\>\"", ",", "\"\<Kilohertz\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmeghz\>\"", ",", "\"\<MHz\>\""}], "}"}], ",", 
       "\"\<Megahertz\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<pF\>\"", ",", "\"\<Picofarads\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmicf\>\"", ",", "\"\<\[Mu]F\>\""}], "}"}], ",", 
       "\"\<Microfarads\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mF\>\"", ",", "\"\<Millifarads\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmich\>\"", ",", "\"\<\[Mu]H\>\""}], "}"}], ",", 
       "\"\<Microhenries\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mH\>\"", ",", "\"\<Millihenries\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qpsi\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\\"lbf\\\"\>\"", ",", "\"\<\[InvisibleSpace]\>\"", ",", 
            "\"\<\\\"/\\\"\>\"", ",", "\"\<\[InvisibleSpace]\>\"", ",", 
            RowBox[{"SuperscriptBox", "[", 
             RowBox[{"\"\<\\\"in\\\"\>\"", ",", "\"\<2\>\""}], "]"}]}], "}"}],
           "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<pounds-force per inch-square\!\(\*TemplateBox[{},
\"QuantityUnit\",
DisplayFunction->(TooltipBox[
StyleBox[
RowBox[{
StyleBox[\"\\\"psi\\\"\", \"QuantityUnitTraditionalLabel\"]}], \
ShowStringCharacters -> False], \"Unit: pounds-force per inch-squared\"]& ),
InterpretationFunction->(RowBox[{\"Quantity\", \"[\", 
If[
(StringTake[
ToString[
Head[#]], -3] === \"Box\"& )[
FractionBox[\"\\\"PoundsForce\\\"\", 
SuperscriptBox[\"\\\"Inches\\\"\", \"2\"]]], 
FractionBox[\"\\\"PoundsForce\\\"\", 
SuperscriptBox[\"\\\"Inches\\\"\", \"2\"]], 
RowBox[{
ToBoxes[
FractionBox[\"\\\"PoundsForce\\\"\", 
SuperscriptBox[\"\\\"Inches\\\"\", \"2\"]]]}]], \"]\"}]& )]\)d\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"FractionBox", "[", 
          RowBox[{"\"\<\\\"PoundsForce\\\"\>\"", ",", 
           RowBox[{"SuperscriptBox", "[", 
            RowBox[{"\"\<\\\"Inches\\\"\>\"", ",", "\"\<2\>\""}], "]"}]}], 
          "]"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<N\>\"", ",", "\"\<Newtons\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<dynes\>\"", ",", "\"\<Dynes\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qozf\>\"", ",", "\"\<ozf\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ounces\[Hyphen]force\>\"", ",", "\"\<OuncesForce\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qlbf\>\"", ",", "\"\<lbf\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<pounds\[Hyphen]force\>\"", ",", "\"\<PoundsForce\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qton\>\"", ",", "\"\<sh tnf\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<short tons\[Hyphen]force\>\"", ",", "\"\<ShortTonsForce\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<J\>\"", ",", "\"\<Joules\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<ergs\>\"", ",", "\"\<Ergs\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<eV\>\"", ",", "\"\<Electronvolts\>\""}], "]"}], ",", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qkcal\>\"", ",", "\"\<kcal\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<thermochemical kilocalories\>\"", ",", 
         "\"\<KilocaloriesThermochemical\>\""}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qcal\>\"", ",", "\"\<cal\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<thermochemical kilocalories\>\"", ",", 
         "\"\<CaloriesThermochemical\>\""}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qftlb\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\\"ft\\\"\>\"", ",", "\"\<\[ThinSpace]\>\"", ",", 
            "\"\<\\\"lbf\\\"\>\""}], "}"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<foot pounds\[Hyphen]force\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\\"Feet\\\"\>\"", ",", "\"\< \>\"", ",", 
            "\"\<\\\"PoundsForce\\\"\>\""}], "}"}], "]"}]}], "}"}]}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qdcal\>\"", ",", "\"\<Cal\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<dietary Calories\>\"", ",", "\"\<LargeCalories\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qbtu\>\"", ",", 
         RowBox[{"SubscriptBox", "[", 
          RowBox[{"\"\<\\\"BTU\\\"\>\"", ",", "\"\<\\\"IT\\\"\>\""}], "]"}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<IT British thermal units\>\"", ",", 
         "\"\<BritishThermalUnitsIT\>\""}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<W\>\"", ",", "\"\<Watts\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<hp\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<horsepower\>\"", ",", "\"\<HorsepowerMechanical\>\""}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<b\>\"", ",", "\"\<Barns\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qac\>\"", ",", "\"\<acres\>\""}], "}"}], ",", 
       "\"\<Acres\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<ha\>\"", ",", "\"\<Hectares\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<L\>\"", ",", "\"\<Liters\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<mL\>\"", ",", "\"\<Milliliters\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qmicl\>\"", ",", "\"\<\[Mu]L\>\""}], "}"}], ",", 
       "\"\<Microliters\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<pL\>\"", ",", "\"\<Picoliters\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<tsp\>\"", ",", "\"\<Teaspoons\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<tbsp\>\"", ",", "\"\<Tablespoons\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<qfoz\>\"", ",", "\"\<fl oz\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<fluid ounces\>\"", ",", "\"\<FluidOunces\>\""}], "}"}]}],
       "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<cups\>\"", ",", "\"\<Cups\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<pt\>\"", ",", "\"\<Pints\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<qt\>\"", ",", "\"\<Quarts\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"aliasRule", "[", 
      RowBox[{"\"\<gal\>\"", ",", "\"\<Gallons\>\""}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.60082850653487*^9, 3.600828554853352*^9}, {
   3.600828595714136*^9, 3.600828764179028*^9}, {3.600828813892797*^9, 
   3.600829004741713*^9}, {3.600829135054831*^9, 3.600829344777935*^9}, {
   3.600831705848578*^9, 3.600831963635785*^9}, {3.600832056141819*^9, 
   3.6008320606955423`*^9}, {3.600860127915968*^9, 3.6008601552991247`*^9}, 
   3.6008602143481083`*^9, 3.600860313804309*^9, {3.600862579250572*^9, 
   3.600862597364965*^9}, 3.600863098994401*^9, {3.60086317634906*^9, 
   3.600863177767188*^9}, {3.6008968967021093`*^9, 3.600896897946108*^9}, 
   3.600897106232583*^9, {3.60177577207863*^9, 3.60177580358672*^9}, {
   3.624018278585011*^9, 3.624018279639154*^9}}],

Cell[BoxData[{
 RowBox[{"End", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"EndPackage", "[", "]"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.600041416131078*^9, 3.600041428511454*^9}}]
},
AutoGeneratedPackage->Automatic,
WindowSize->{740, 795},
WindowMargins->{{Automatic, 531}, {Automatic, 1}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September 9, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 176, 3, 36, "Input",
 InitializationCell->True],
Cell[736, 25, 411, 9, 78, "Input",
 InitializationCell->True],
Cell[1150, 36, 450, 10, 99, "Input",
 InitializationCell->True],
Cell[1603, 48, 169, 3, 36, "Input",
 InitializationCell->True],
Cell[1775, 53, 1302, 30, 183, "Input",
 InitializationCell->True],
Cell[3080, 85, 4369, 113, 540, "Input",
 InitializationCell->True],
Cell[7452, 200, 22455, 541, 3097, "Input",
 InitializationCell->True],
Cell[29910, 743, 205, 4, 57, "Input",
 InitializationCell->True]
}
]
*)

(* End of internal cache information *)
